@@ -4,40 +4,38 @@ OC.L10N.register(
     "Details" : "Detalles",
     "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
-    "Loading contacts …" : "Cargando contactos ...",
-    "Loading …" : "Cargando …",
-    "General settings" : "Configuraciones generales",
     "Rename" : "Renombrar",
     "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
     "Copy link" : "Copiar liga",
     "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
-    "can edit" : "puede editar",
+    "Cancel" : "Cancelar",
     "Add" : "Agregar",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
     "Save" : "Guardar",
-    "Cancel" : "Cancelar",
+    "Close" : "Cerrar",
+    "Folder" : "Folder",
+    "Create" : "Crear",
     "Invalid image" : "Imagen inválida",
     "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
     "Title" : "Título",
-    "Search contacts …" : "Buscar contactos ...",
+    "Move" : "Move",
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
     "None" : "Ninguno",
+    "Member" : "Miembro",
     "New contact" : "Nuevo contacto",
-    "Close" : "Cerrar",
     "Import" : "Importar",
     "Not grouped" : "No agrupado",
     "User" : "Usuario",
     "Group" : "Grupo",
     "Email" : "Correo electrónico",
     "Contact" : "Contacto",
-    "Member" : "Miembro",
     "Moderator" : "Moderador",
     "Admin" : "Admin",
     "Owner" : "Dueño",
@@ -93,8 +91,10 @@ OC.L10N.register(
     "Female" : "Femenino",
     "Male" : "Masculino",
     "Unknown" : "Desconocido",
-    "Password protection" : "Protección con contraseña",
-    "Description" : "Descripción",
-    "Settings" : "Settings"
+    "Loading contacts …" : "Cargando contactos ...",
+    "Loading …" : "Cargando …",
+    "General settings" : "Configuraciones generales",
+    "can edit" : "puede editar",
+    "Search contacts …" : "Buscar contactos ..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
